Crate const_json

Crate const_json 

Provides a way to embed and access const JSON in Rust code, using a single macro_rules declaration, and no dependencies, so it is quick to compile. See const_json.

Macros

const_json
Declares a borrowed JSON structure without allocation at compile time. Valid JSON syntax works, as well as one-token Rust expressions (such as a variable name). If you want to embed a more complex expression, just surround it with parentheses.

Enums

Json
The result of a const_json macro call.